==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/codebuild/kotlin/inputs/ProjectSourceBuildStatusConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.codebuild.kotlin.inputs

import com.pulumi.aws.codebuild.inputs.ProjectSourceBuildStatusConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property context Specifies the context of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.
 * @property targetUrl Specifies the target url of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.
 */
public data class ProjectSourceBuildStatusConfigArgs(
    public val context: Output<String>? = null,
    public val targetUrl: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.codebuild.inputs.ProjectSourceBuildStatusConfigArgs> {
    override fun toJava(): com.pulumi.aws.codebuild.inputs.ProjectSourceBuildStatusConfigArgs =
        com.pulumi.aws.codebuild.inputs.ProjectSourceBuildStatusConfigArgs.builder()
            .context(context?.applyValue({ args0 -> args0 }))
            .targetUrl(targetUrl?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ProjectSourceBuildStatusConfigArgs].
 */
@PulumiTagMarker
public class ProjectSourceBuildStatusConfigArgsBuilder internal constructor() {
    private var context: Output<String>? = null

    private var targetUrl: Output<String>? = null

    /**
     * @param value Specifies the context of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.
     */
    @JvmName("vhmlbgbwkaabuyrr")
    public suspend fun context(`value`: Output<String>) {
        this.context = value
    }

    /**
     * @param value Specifies the target url of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.
     */
    @JvmName("orhdyjasddtbhcxi")
    public suspend fun targetUrl(`value`: Output<String>) {
        this.targetUrl = value
    }

    /**
     * @param value Specifies the context of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.
     */
    @JvmName("qqtlabcjwrvkhxcu")
    public suspend fun context(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.context = mapped
    }

    /**
     * @param value Specifies the target url of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.
     */
    @JvmName("xuymggkdrsrockxr")
    public suspend fun targetUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetUrl = mapped
    }

    internal fun build(): ProjectSourceBuildStatusConfigArgs = ProjectSourceBuildStatusConfigArgs(
        context = context,
        targetUrl = targetUrl,
    )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/codebuild/kotlin/inputs/ProjectSourceBuildStatusConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.codebuild.kotlin.inputs

import com.pulumi.aws.codebuild.inputs.ProjectSourceBuildStatusConfigArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property context Specifies the context of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.
 * @property targetUrl Specifies the target url of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.
 */
public data class ProjectSourceBuildStatusConfigArgs(
    public val context: Output<String>? = null,
    public val targetUrl: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.aws.codebuild.inputs.ProjectSourceBuildStatusConfigArgs> {
    override fun toJava(): com.pulumi.aws.codebuild.inputs.ProjectSourceBuildStatusConfigArgs =
        com.pulumi.aws.codebuild.inputs.ProjectSourceBuildStatusConfigArgs.builder()
            .context(context?.applyValue({ args0 -> args0 }))
            .targetUrl(targetUrl?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ProjectSourceBuildStatusConfigArgs].
 */
@PulumiTagMarker
public class ProjectSourceBuildStatusConfigArgsBuilder internal constructor() {
    private var context: Output<String>? = null

    private var targetUrl: Output<String>? = null

    /**
     * @param value Specifies the context of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.
     */
    @JvmName("nyhteophqhcqfegj")
    public suspend fun context(`value`: Output<String>) {
        this.context = value
    }

    /**
     * @param value Specifies the target url of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.
     */
    @JvmName("tfivalcpdqeqsdat")
    public suspend fun targetUrl(`value`: Output<String>) {
        this.targetUrl = value
    }

    /**
     * @param value Specifies the context of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.
     */
    @JvmName("vchujeedbycnujfu")
    public suspend fun context(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.context = mapped
    }

    /**
     * @param value Specifies the target url of the build status CodeBuild sends to the source provider. The usage of this parameter depends on the source provider.
     */
    @JvmName("dpwprnplmefnhgqr")
    public suspend fun targetUrl(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetUrl = mapped
    }

    internal fun build(): ProjectSourceBuildStatusConfigArgs = ProjectSourceBuildStatusConfigArgs(
        context = context,
        targetUrl = targetUrl,
    )
}
